@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.116;
+our $VERSION = 1.117;
 
 use Prty::Option;
 use Prty::Ipc;
@@ -308,7 +308,7 @@ sub analyzeFile {
             print "$cmd\n";
         }
 
-        my ($xml) = Prty::Ipc->filter($cmd,undef);
+        my ($xml) = Prty::Ipc->filter($cmd);
 
         # Breite, Höhe
 
@@ -360,7 +360,7 @@ sub analyzeFile {
 
 =head1 VERSION
 
-1.116
+1.117
 
 =head1 AUTHOR
 
